TextSpanStyle class

Constructors

TextSpanStyle({required Color color, required double fontSize, FontWeight? fontWeight, Color? markTextColor, double? markFontSize})

Properties

color → Color
颜色
final
fontSize → double
字体大小
final
fontWeight → FontWeight?
文本权重
final
hashCode → int
The hash code for this object.
no setterinherited
markFontSize → double?
标注文本大小
final
markTextColor → Color?
标注文本颜色
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited