Node class abstract

Base class for any AST item.

Roughly corresponds to Node in the DOM. Will be either an Element or Text.

Implementers

Constructors

Node()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textContent → String
no setter

Methods

accept(NodeVisitor visitor) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited