BlockSyntax class abstract

Implementers

Constructors

BlockSyntax()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
Gets the regex used to identify the beginning of this block, if any.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canEndBlock(BlockParser parser) → bool
canParse(BlockParser parser) → bool
interruptedBy(BlockParser parser) → BlockSyntax?
Returns the block which interrupts current syntax parsing if there is one, otherwise returns null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node?
parseChildLines(BlockParser parser) → List<Line?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generateAnchorHash(Element element) → String
Generates a valid HTML anchor from the inner text of element.
isAtBlockEnd(BlockParser parser) → bool
Gets whether or not parser's current line should end the previous block.