FencedCodeBlockSyntax class

Parses preformatted code blocks between two ~~~ or ``` sequences.

See the CommonMark spec: https://spec.commonmark.org/0.29/#fenced-code-blocks

Inheritance

Constructors

FencedCodeBlockSyntax()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
Gets the regex used to identify the beginning of this block, if any.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canEndBlock(BlockParser parser) → bool
inherited
canParse(BlockParser parser) → bool
inherited
interruptedBy(BlockParser parser) → BlockSyntax?
Returns the block which interrupts current syntax parsing if there is one, otherwise returns null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node
override
parseChildLines(BlockParser parser, [String openingMarker = '', int indent = 0]) → List<Line>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited