Document class

Maintains the context needed to parse a Markdown document.

Constructors

Document({Iterable<BlockSyntax>? blockSyntaxes, Iterable<InlineSyntax>? inlineSyntaxes, ExtensionSet? extensionSet, Resolver? linkResolver, Resolver? imageLinkResolver, bool encodeHtml = true, bool withDefaultBlockSyntaxes = true, bool withDefaultInlineSyntaxes = true})

Properties

blockSyntaxes → Iterable<BlockSyntax>
no setter
encodeHtml → bool
final
footnoteLabels → List<String>
Footnotes labels by appearing order, are case-insensitive and added by ref syntax.
final
footnoteReferences → Map<String, int>
Footnote ref count, keys are case-sensitive and added by define syntax.
final
hasCustomInlineSyntaxes → bool
final
hashCode → int
The hash code for this object.
no setterinherited
imageLinkResolver → Resolver?
final
inlineSyntaxes → Iterable<InlineSyntax>
no setter
linkReferences → Map<String, LinkReference>
final
linkResolver → Resolver?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withDefaultBlockSyntaxes → bool
Whether to use default block syntaxes.
final
withDefaultInlineSyntaxes → bool
Whether to use default inline syntaxes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → List<Node>
Parses the given text to a series of AST nodes.
parseInline(String text) → List<Node>
Parses the given inline Markdown text to a series of AST nodes.
parseLineList(List<Line> lines) → List<Node>
Parses the given lines of Line to a series of AST nodes.
parseLines(List<String> lines) → List<Node>
Parses the given lines of Markdown to a series of AST nodes.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited