LinkReference class

Constructors

LinkReference(String label, String destination, String? title)
Construct a new LinkReference, with all necessary fields.

Properties

destination → String
The link destination.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
The link label.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The link title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited