DelimiterSyntax class

Matches syntax that has a pair of tags and becomes an element, like * for <em>. Allows nested tags.

Inheritance
Implementers

Constructors

DelimiterSyntax(String pattern, {bool requiresDelimiterRun = false, int? startCharacter, bool allowIntraWord = false, List<DelimiterTag>? tags})
Creates a new DelimiterSyntax which matches text on pattern.

Properties

allowIntraWord → bool
Whether to allow intra-word delimiter runs. CommonMark emphasis and strong emphasis does not allow this, but GitHub-Flavored Markdown allows it on strikethrough.
final
hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
finalinherited
requiresDelimiterRun → bool
Whether this is parsed according to the same nesting rules as emphasis delimiters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<DelimiterTag>?
final

Methods

close(InlineParser parser, Delimiter opener, Delimiter closer, {required String tag, required List<Node> getChildren()}) → Iterable<Node>?
Attempts to close this tag at the current position.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMatch(InlineParser parser, Match match) → bool
Processes match, adding nodes to parser and possibly advancing parser.
override
toString() → String
A string representation of this object.
inherited
tryMatch(InlineParser parser, [int? startMatchPos]) → bool
Tries to match at the parser's current position.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited