StrikethroughSyntax class

Matches strikethrough syntax according to the GFM spec.

Inheritance

Constructors

StrikethroughSyntax()

Properties

allowIntraWord → bool
Whether to allow intra-word delimiter runs. CommonMark emphasis and strong emphasis does not allow this, but GitHub-Flavored Markdown allows it on strikethrough.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
finalinherited
requiresDelimiterRun → bool
Whether this is parsed according to the same nesting rules as emphasis delimiters.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<DelimiterTag>?
finalinherited

Methods

close(InlineParser parser, Delimiter opener, Delimiter closer, {required String tag, required List<Node> getChildren()}) → Iterable<Node>?
Attempts to close this tag at the current position.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMatch(InlineParser parser, Match match) → bool
Processes match, adding nodes to parser and possibly advancing parser.
inherited
toString() → String
A string representation of this object.
inherited
tryMatch(InlineParser parser, [int? startMatchPos]) → bool
Tries to match at the parser's current position.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited