LinkParser class

Inheritance

Constructors

LinkParser(String source)

Properties

destination → String?
Link destination.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDone → bool
Whether the read position has reached the end of source.
no setterinherited
label → String?
Link label.
no setter
length → int
The length of source.
no setterinherited
pos → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
finalinherited
title → String?
Link title.
no setter
unconsumedLines → int
How many lines of the source have been consumed by link reference definition.
no setter
valid → bool
If there is a valid link formed.
no setter

Methods

advance() → void
Moves the read position one character ahead.
inherited
advanceBy(int length) → void
Moves the read position for length characters. length can be negative.
inherited
charAt([int? position]) → int
inherited
moveThroughWhitespace({bool multiLine = false}) → int
Walk the parser forward through any whitespace.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDefinition() → void
Parses source to a link reference definition.
parseLabel() → bool
Parses the link label, returns true if there is a valid link label.
substring(int start, [int? end]) → String
Substrings the source and returns a String.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited