delta/html/patterns library

Constants

asciiPunctuationCharacters → const String
ASCII punctuation characters.
asciiPunctuationEscaped → const String
ASCII punctuation characters with some characters escaped, in order to be
namedTagDefinition → const String
A String pattern to match a named tag like <table> or </table>.

Properties

blockquoteFencePattern → RegExp
Fenced blockquotes.
final
blockquotePattern → RegExp
The line starts with > with one optional space after.
final
codeFencePattern → RegExp
Fenced code block.
final
dummyPattern → RegExp
A pattern which should never be used. It just satisfies non-nullability of pattern fields.
final
emptyPattern → RegExp
The line contains only whitespace or is empty.
final
footnotePattern → RegExp
A line starting with [^ and contains with ]:, but without special chars (\] \r\n\x00\t) between. Same as GFM.
final
headerPattern → RegExp
Leading (and trailing) # define atx-style headers.
final
hrPattern → RegExp
Three or more hyphens, asterisks or underscores by themselves. Note that a line like ---- is valid as both HR and SETEXT. In case of a tie, SETEXT should win.
final
htmlBlockPattern → RegExp
A pattern to match the start of an HTML block.
final
htmlCharactersPattern → RegExp
A pattern to match HTML entity references and numeric character references.
final
indentPattern → RegExp
A line indented four spaces. Used for code blocks and lists.
final
linkReferenceDefinitionPattern → RegExp
A line starts with [.
final
listPattern → RegExp
Unordered list A line starting with one of these markers: -, *, +. May have up to three leading spaces before the marker and any number of spaces or tabs after.
final
setextPattern → RegExp
A series of = or - (on the next line) define setext-style headers.
final
tablePattern → RegExp
A line of hyphens separated by at least one pipe.
final