BlockHtmlSyntax class abstract

Parses inline HTML at the block level. This differs from other Markdown implementations in several ways:

  1. This one is way way WAY simpler.
  2. Essentially no HTML parsing or validation is done. We're a Markdown parser, not an HTML parser!
Inheritance
Implementers

Constructors

BlockHtmlSyntax()
const

Properties

canEndBlock → bool
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp?
Gets the regex used to identify the beginning of this block, if any.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canParse(BlockParser parser) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node?
inherited
parseChildLines(BlockParser parser) → List<String?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited