BlockParser class

Maintains the internal state needed to parse a series of lines into blocks of Markdown suitable for further inline parsing.

Constructors

BlockParser(List<String> lines, Document document)

Properties

blockSyntaxes → List<BlockSyntax>
The enabled block syntaxes.
final
current → String
Gets the current line.
no setter
document → Document
The Markdown document this parser is parsing.
final
encounteredBlankLine ↔ bool
Whether the parser has encountered a blank line between two block-level elements.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDone → bool
no setter
lines → List<String>
final
next → String?
Gets the line after the current one or null if there is none.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardBlockSyntaxes → List<BlockSyntax>
The collection of built-in block parsers.
final

Methods

advance() → void
matches(RegExp regex) → bool
Gets whether or not the current line matches the given pattern.
matchesNext(RegExp regex) → bool
Gets whether or not the next line matches the given pattern.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseLines() → List<Node>
peek(int linesAhead) → String?
Gets the line that is linesAhead lines ahead of the current one, or null if there is none.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited