HeaderSyntax class

Parses atx-style headers: ## Header ##.

Inheritance
Implementers

Constructors

HeaderSyntax()
const

Properties

canEndBlock → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
Gets the regex used to identify the beginning of this block, if any.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canParse(BlockParser parser) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node
override
parseChildLines(BlockParser parser) → List<String?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited