LongBlockHtmlSyntax class

A BlockHtmlSyntax that has a specific endPattern.

In practice this means that the syntax dominates; it is allowed to eat many lines, including blank lines, before matching its endPattern.

Inheritance

Constructors

LongBlockHtmlSyntax(String pattern, String endPattern)

Properties

canEndBlock → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
Gets the regex used to identify the beginning of this block, if any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canParse(BlockParser parser) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node
override
parseChildLines(BlockParser parser) → List<String?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited