OrderedListSyntax class

Parses ordered lists.

Inheritance

Constructors

OrderedListSyntax()
const

Properties

canEndBlock → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
listTag → String
no setteroverride
pattern → RegExp
Gets the regex used to identify the beginning of this block, if any.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canParse(BlockParser parser) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node
inherited
parseChildLines(BlockParser parser) → List<String?>
inherited
removeLeadingEmptyLine(ListItem item) → void
inherited
removeTrailingEmptyLines(List<ListItem> items) → bool
Removes any trailing empty lines and notes whether any items are separated by such lines.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited