TableSyntax class

Parses tables.

Inheritance

Constructors

TableSyntax()
const

Properties

canEndBlock → bool
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp?
Gets the regex used to identify the beginning of this block, if any.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canParse(BlockParser parser) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) → Node?
Parses a table into its three parts:
override
parseAlignments(String line) → List<String?>
parseChildLines(BlockParser parser) → List<String?>
inherited
parseRow(BlockParser parser, List<String?> alignments, String cellType) → Element
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited