AutolinkSyntax class

Matches autolinks like <http://foo.com>.

Inheritance

Constructors

AutolinkSyntax()

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → RegExp
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMatch(InlineParser parser, Match match) → bool
Processes match, adding nodes to parser and possibly advancing parser.
override
toString() → String
A string representation of this object.
inherited
tryMatch(InlineParser parser, [int? startMatchPos]) → bool
Tries to match at the parser's current position.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited