InlineParser class

Maintains the internal state needed to parse inline span elements in Markdown.

Constructors

InlineParser(String source, Document document)

Properties

document → Document
The Markdown document this parser is parsing.
final
hashCode → int
The hash code for this object.
no setterinherited
isDone → bool
no setter
pos ↔ int
The current read position.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
The string of Markdown being parsed.
final
start ↔ int
Starting position of the last unconsumed text.
getter/setter pair
syntaxes → List<InlineSyntax>
final

Methods

addNode(Node node) → void
Add node to the last TagState on the stack.
advanceBy(int length) → void
charAt(int index) → int
consume(int length) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openTag(TagState state) → void
Push state onto the stack of TagStates.
parse() → List<Node>?
toString() → String
A string representation of this object.
inherited
writeText() → void
writeTextRange(int start, int end) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited