LinkSyntax class

Matches links like [blah][label] and [blah](url).

Inheritance
Implementers

Constructors

LinkSyntax({Resolver? linkResolver, String pattern = r'\['})

Properties

endPattern → RegExp
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
linkResolver → Resolver
final
pattern → RegExp
finalinherited
requiresDelimiterRun → bool
Whether this is parsed according to the same nesting rules as emphasis delimiters.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMatch(InlineParser parser, Match match) → bool
Processes match, adding nodes to parser and possibly advancing parser.
override
onMatchEnd(InlineParser parser, Match match, TagState state) → bool
override
toString() → String
A string representation of this object.
inherited
tryMatch(InlineParser parser, [int? startMatchPos]) → bool
Tries to match at the parser's current position.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited