AlignDialog class

Constructors

AlignDialog()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
quillController ↔ QuillController?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildAlignMenus() → Widget
buildAlignPanel() → Widget
buildBothAlign() → Widget
buildCenterAlign() → Widget
buildLeftAlign() → Widget
buildRightAlign() → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show({required BuildContext context, QuillController? controller}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → AlignDialog
no setter