Attribute<T> class

Implementers

Constructors

Attribute(String key, AttributeScope scope, T value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isBlockExceptHeader → bool
no setter
isInline → bool
no setter
key → String
Unique key of this attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → AttributeScope
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

blockKeys → Set<String>
final
blockKeysExceptHeader → Set<String>
final
exclusiveBlockKeys → Set<String>
final
inlineKeys → Set<String>
final

Static Methods

clone(Attribute origin, dynamic value) → Attribute
fromKeyValue(String key, dynamic value) → Attribute?
getIndentLevel(int? level) → Attribute<int?>
getRegistryOrder(Attribute attribute) → int

Constants

align → const AlignAttribute
background → const BackgroundAttribute
blockQuote → const BlockQuoteAttribute
bold → const BoldAttribute
centerAlignment → const Attribute<String?>
checked → const Attribute<String?>
codeBlock → const CodeBlockAttribute
color → const ColorAttribute
direction → const DirectionAttribute
font → const FontAttribute
h1 → const Attribute<int?>
h2 → const Attribute<int?>
h3 → const Attribute<int?>
height → const HeightAttribute
indent → const IndentAttribute
indentL1 → const Attribute<int?>
indentL2 → const Attribute<int?>
indentL3 → const Attribute<int?>
inlineCode → const InlineCodeAttribute
italic → const ItalicAttribute
justifyAlignment → const Attribute<String?>
leftAlignment → const Attribute<String?>
list → const ListAttribute
mobileAlignment → const String
mobileHeight → const String
mobileMargin → const String
mobileWidth → const String
ol → const Attribute<String?>
placeholder → const PlaceholderAttribute
rightAlignment → const Attribute<String?>
rtl → const Attribute<String?>
script → const ScriptAttribute
size → const SizeAttribute
small → const SmallAttribute
strikeThrough → const StrikeThroughAttribute
style → const StyleAttribute
token → const TokenAttribute
ul → const Attribute<String?>
unchecked → const Attribute<String?>
underline → const UnderlineAttribute
width → const WidthAttribute