ScriptAttribute class

Inheritance

Constructors

ScriptAttribute(String val)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBlockExceptHeader → bool
no setterinherited
isInline → bool
no setterinherited
key → String
Unique key of this attribute.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → AttributeScope
finalinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited