ChildQuery class

Result of a child query in a Container.

Constructors

ChildQuery(Node? node, int offset)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Returns true if there is no child node found, e.g. node is null.
no setter
isNotEmpty → bool
Returns true node is not null.
no setter
node → Node?
The child node if found, otherwise null.
final
offset → int
Starting offset within the child node which points at the same character in the document as the original offset passed to Container.queryChild method.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited