Leaf class abstract

A leaf in Quill document tree.

Inheritance
Implementers

Constructors

Leaf(Object data)
Creates a new Leaf with specified data.
factory
Leaf.val(Object val)

Properties

documentOffset → int
Offset in characters of this node in the document.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isFirst → bool
Returns true if this node is the first node in the parent list.
no setterinherited
isLast → bool
Returns true if this node is the last node in the parent list.
no setterinherited
length → int
Length of this node in characters.
no setteroverride
list → LinkedList<Node>?
The linked list containing this element.
no setterinherited
next → Node?
The successor of this element in its linked list.
no setterinherited
offset → int
Offset in characters of this node relative to parent node.
no setterinherited
parent ↔ Line?
Current parent of this node. May be null if this node is not mounted.
getter/setter pairinherited-setteroverride-getter
previous → Node?
The predecessor of this element in its linked list.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → Style
no setterinherited
value → Object
Contents of this node, either a String if this is a Text or an Embed if this is an BlockEmbed.
no setter

Methods

adjust() → void
Adjust this text node by merging it with adjacent nodes if they share the same style.
override
applyAttribute(Attribute attribute) → void
inherited
applyStyle(Style value) → void
override
clearStyle() → void
inherited
clone() → Node
inherited
containsOffset(int offset) → bool
Returns true if this node contains character at specified offset in the document.
inherited
cutAt(int index) → Leaf?
Cuts a leaf from index to the end of this node and returns new node in detached state (e.g. mounted returns false).
delete(int index, int? len) → void
override
format(Style? style) → void
Formats this node and optimizes it with adjacent leaf nodes if needed.
insert(int index, Object data, Style? style) → void
override
insertAfter(Node entry) → void
Insert an element after this element in this element's linked list.
inherited
insertBefore(Node entry) → void
Insert an element before this element in this element's linked list.
inherited
newInstance() → Node
abstract methods begin
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retain(int index, int? len, Style? style) → void
override
splitAt(int index) → Leaf?
Splits this leaf node at index and returns new node.
toDelta() → Delta
override
toPlainText() → String
inherited
toString() → String
A string representation of this object.
override
Unlink the element from its linked list.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited