Style class

Constructors

Style()
Style.attr(Map<String, Attribute> _attributes)

Properties

attributes → Map<String, Attribute>
no setter
hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
no setter
isIgnored → bool
no setter
isInline → bool
no setter
isNotEmpty → bool
no setter
keys → Iterable<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → Attribute
no setter
values → Iterable<Attribute>
no setter

Methods

containsKey(String key) → bool
getBlockExceptHeader() → Attribute?
getBlocksExceptHeader() → Map<String, Attribute>
merge(Attribute attribute) → Style
mergeAll(Style other) → Style
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(Attribute attribute) → Style
removeAll(Set<Attribute> attributes) → Style
toJson() → Map<String, dynamic>?
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? attributes) → Style