FormatRule class abstract

A heuristic rule for format (retain) operations.

Inheritance
Implementers

Constructors

FormatRule()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → RuleType
no setteroverride

Methods

apply(Delta document, int index, {int? len, Object? data, Attribute? attribute}) → Delta?
inherited
applyRule(Delta document, int index, {int? len, Object? data, Attribute? attribute}) → Delta?
Applies heuristic rule to an operation on a document and returns resulting Delta.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateArgs(int? len, Object? data, Attribute? attribute) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited