RichTextEditor class

Inheritance

Constructors

RichTextEditor({Key? key, Color? backgroundColor, EdgeInsetsGeometry? padding, String? hint, Color? cursorColor, Color? toolBarColor, required dynamic buildCall(RichTextModel? richTextModel), dynamic imageCall()?, String? initialize, bool readOnly = false, dynamic removeImageCall(String imageUrl)?, Widget customHeaderView()?, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, BorderRadiusGeometry? borderRadius, BoxBorder? border, Color? textColor, double textSize = 14, Color? placeHolderColor = const Color(0x333B372C), double placeHolderTextSize = 14})
const

Properties

backgroundColor → Color?
背景颜色
final
border → BoxBorder?
边框
final
borderRadius → BorderRadiusGeometry?
边框圆角
final
buildCall → dynamic Function(RichTextModel? richTextModel)
组件构建后回调
final
crossAxisAlignment → CrossAxisAlignment
副坐标对齐方式
final
cursorColor → Color?
光标颜色
final
customHeaderView → Widget Function()?
自定义头视图
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
空内容时提示信息
final
imageCall → dynamic Function()?
追加图片回调
final
initialize → String?
初始化文档内容
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry?
编辑器内边距
final
placeHolderColor → Color?
占位符颜色
final
placeHolderTextSize → double
占位符文本大小
final
readOnly → bool
是否只读
final
removeImageCall → dynamic Function(String imageUrl)?
移除图片回调
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color?
文本颜色
final
textSize → double
文本大小
final
toolBarColor → Color?
工具条颜色
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _RichTextEditorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited