QuillController class

Inheritance

Constructors

QuillController({required Document document, required TextSelection selection, bool keepStyleOnNewLine = false, ReplaceTextCallback? onReplaceText, DeleteCallback? onDelete, void onSelectionCompleted()?, void onSelectionChanged(TextSelection textSelection)?})
QuillController.basic()
factory

Properties

changes → Stream<DocChange>
no setter
copiedImageUrl ↔ ImageUrl?
getter/setter pair
document ↔ Document
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasRedo → bool
no setter
hasUndo → bool
no setter
ignoreFocusOnTextChange ↔ bool
getter/setter pair
onDelete ↔ DeleteCallback?
Custom delete handler
getter/setter pair
onReplaceText ↔ ReplaceTextCallback?
Custom replaceText handler Return false to ignore the event
getter/setter pair
onSelectionChanged ↔ void Function(TextSelection textSelection)?
getter/setter pair
onSelectionCompleted ↔ void Function()?
getter/setter pair
plainTextEditingValue → TextEditingValue
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → TextSelection
Currently selected text within the document.
no setter
skipRequestKeyboard ↔ bool
Skip requestKeyboard being called in RawEditorState#_didChangeTextEditingValue
getter/setter pair
toggledStyle ↔ Style
Store any styles attribute that got toggled by the tap of a button and that has not been applied yet. It gets reset after each format action within the document.
getter/setter pair
toolbarButtonToggler ↔ Map<String, Attribute>
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
override
clear() → void
clear editor
compose(Delta delta, TextSelection textSelection, ChangeSource source) → void
dispose() → void
Discards any resources used by the object.
override
formatSelection(Attribute? attribute) → void
formatText(int index, int len, Attribute? attribute) → void
formatTextStyle(int index, int len, Style style) → void
getAllIndividualSelectionStyles() → List<OffsetValue<Style>>
Returns all styles for each node within selection
getAllSelectionStyles() → List<Style>
Returns all styles for any character within the specified text range.
getPlainText() → String
Returns plain text for each node within selection
getSelectionStyle() → Style
Only attributes applied to all characters within this range are included in the result.
handleDelete(int cursorPosition, bool forward) → void
Called in two cases: forward == false && textBefore.isEmpty forward == true && textAfter.isEmpty Android only see https://github.com/singerdmx/flutter-quill/discussions/514
indentSelection(bool isIncrease) → void
moveCursorToEnd() → void
moveCursorToPosition(int position) → void
moveCursorToStart() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
queryNode(int offset) → Leaf?
Given offset, find its leaf node in document
redo() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
override
replaceText(int index, int len, Object? data, TextSelection? textSelection, {bool ignoreFocus = false}) → void
toString() → String
A string representation of this object.
inherited
undo() → void
updateSelection(TextSelection textSelection, ChangeSource source) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited