CursorStyle class

Style properties of editing cursor.

Constructors

CursorStyle({required Color color, required Color backgroundColor, double width = 1.0, double? height, Radius? radius, Offset? offset, bool opacityAnimates = false, bool paintAboveText = false})
const

Properties

backgroundColor → Color
The color to use when painting the background cursor aligned with the text while rendering the floating cursor.
final
color → Color
The color to use when painting the cursor.
final
hashCode → int
The hash code for this object.
no setteroverride
height → double?
How tall the cursor will be.
final
offset → Offset?
The offset that is used, in pixels, when painting the cursor on screen.
final
opacityAnimates → bool
Whether the cursor will animate from fully transparent to fully opaque during each cursor blink.
final
paintAboveText → bool
If the cursor should be painted on top of the text or underneath it.
final
radius → Radius?
How rounded the corners of the cursor should be.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
How thick the cursor will be.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override