InlineCodeStyle class

Theme data for inline code.

Constructors

InlineCodeStyle({required TextStyle style, TextStyle? header1, TextStyle? header2, TextStyle? header3, Color? backgroundColor, Radius? radius})

Properties

backgroundColor → Color?
Background color for inline code.
final
hashCode → int
The hash code for this object.
no setteroverride
header1 → TextStyle?
Style override for inline code in header level 1.
final
header2 → TextStyle?
Style override for inline code in headings level 2.
final
header3 → TextStyle?
Style override for inline code in headings level 3.
final
radius → Radius?
Radius used when paining the background.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle
Base text style for an inline code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
styleFor(Style lineStyle) → TextStyle
Returns effective style to use for inline code for the specified lineStyle.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override