EditorState class abstract

Base interface for the editor state which defines contract used by various mixins.

Inheritance
Implemented types
Implementers

Constructors

EditorState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
copyEnabled → bool
Whether copy is enabled.
no setterinherited
cutEnabled → bool
Whether cut is enabled.
no setterinherited
floatingCursorResetController → AnimationController
Controls the floating cursor animation when it is released. The floating cursor is animated to merge with the regular cursor.
no setter
hashCode → int
The hash code for this object.
no setterinherited
liveTextInputEnabled → bool
Whether Live Text input is enabled.
no setterinherited
lookUpEnabled → bool
Whether look up is enabled.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
pasteEnabled → bool
Whether paste is enabled.
no setterinherited
pastePlainText → String
no setter
pasteStyle → List<OffsetValue<Style>>
no setter
renderEditor → RenderEditor
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController
no setter
searchWebEnabled → bool
Whether search web is enabled.
no setterinherited
selectAllEnabled → bool
Whether select all is enabled.
no setterinherited
selectionOverlay → EditorTextSelectionOverlay?
no setter
shareEnabled → bool
Whether share is enabled.
no setterinherited
textEditingValue → TextEditingValue
Gets the current text input.
no setterinherited
widget → RawEditor
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
bringIntoView(TextPosition position) → void
Brings the provided TextPosition into the visible area of the text input.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
copySelection(SelectionChangedCause cause) → void
Copy current selection to Clipboard.
inherited
cutSelection(SelectionChangedCause cause) → void
Cut current selection to Clipboard.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant RawEditor oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
hideToolbar([bool hideHandles = true]) → void
Hides the text selection toolbar.
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pasteText(SelectionChangedCause cause) → Future<void>
Paste text from Clipboard.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
requestKeyboard() → void
selectAll(SelectionChangedCause cause) → void
Set the current selection to contain the entire text value.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showToolbar() → bool
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
userUpdateTextEditingValue(TextEditingValue value, SelectionChangedCause cause) → void
Indicates that the user has requested the delegate to replace its current text editing state with value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited