EmbedBuilder class abstract

Implementers

Constructors

EmbedBuilder()
const

Properties

expanded → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, QuillController controller, Embed node, bool readOnly, bool inline) → Widget
buildWidgetSpan(Widget widget) → WidgetSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited