RawEditor class

Inheritance

Constructors

RawEditor({required QuillController controller, required FocusNode focusNode, required ScrollController scrollController, required double scrollBottomInset, required CursorStyle cursorStyle, required Color selectionColor, required TextSelectionControls selectionCtrls, required EmbedsBuilder embedBuilder, Key? key, bool scrollable = true, EdgeInsetsGeometry padding = EdgeInsets.zero, bool readOnly = false, String? placeholder, ValueChanged<String>? onLaunchUrl, QuillEditorContextMenuBuilder? contextMenuBuilder = defaultContextMenuBuilder, bool showSelectionHandles = false, bool? showCursor, TextCapitalization textCapitalization = TextCapitalization.none, double? maxHeight, double? minHeight, double? maxContentWidth, DefaultStyles? customStyles, Map<LogicalKeySet, Intent>? customShortcuts, Map<Type, Action<Intent>>? customActions, bool expands = false, bool autoFocus = false, bool enableUnfocusOnTapOutside = true, Brightness keyboardAppearance = Brightness.light, bool enableInteractiveSelection = true, ScrollPhysics? scrollPhysics, LinkActionPickerDelegate linkActionPickerDelegate = defaultLinkActionPickerDelegate, CustomStyleBuilder? customStyleBuilder, bool floatingCursorDisabled = false, Future<String?> onImagePaste(Uint8List imageBytes)?, List<String> customLinkPrefixes = const <String>[]})
const

Properties

autoFocus → bool
Whether this editor should focus itself if nothing else is already focused.
final
contextMenuBuilder → QuillEditorContextMenuBuilder?
Builds the text selection toolbar when requested by the user.
final
controller → QuillController
Controls the document being edited.
final
cursorStyle → CursorStyle
The style to be used for the editing cursor.
final
customActions → Map<Type, Action<Intent>>?
final
customLinkPrefixes → List<String>
final
customShortcuts → Map<LogicalKeySet, Intent>?
final
customStyleBuilder → CustomStyleBuilder?
final
customStyles → DefaultStyles?
final
embedBuilder → EmbedsBuilder
Builder function for embeddable objects.
final
enableInteractiveSelection → bool
If true, then long-pressing this TextField will select text and show the cut/copy/paste menu, and tapping will move the text caret.
final
enableUnfocusOnTapOutside → bool
final
expands → bool
Whether this widget's height will be sized to fill its parent.
final
floatingCursorDisabled → bool
final
focusNode → FocusNode
Controls whether this editor has keyboard focus.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness
The appearance of the keyboard.
final
linkActionPickerDelegate → LinkActionPickerDelegate
final
maxContentWidth → double?
The maximum width to be occupied by the content of this editor.
final
maxHeight → double?
The maximum height this editor can have.
final
minHeight → double?
The minimum height this editor can have.
final
onImagePaste → Future<String?> Function(Uint8List imageBytes)?
final
onLaunchUrl → ValueChanged<String>?
Callback which is triggered when the user wants to open a URL from a link in the document.
final
padding → EdgeInsetsGeometry
Additional space around the editor contents.
final
placeholder → String?
final
readOnly → bool
Whether the text can be changed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → bool
final
scrollBottomInset → double
final
scrollController → ScrollController
final
scrollPhysics → ScrollPhysics?
The ScrollPhysics to use when vertically scrolling the input.
final
selectionColor → Color
The color to use when painting the selection.
final
selectionCtrls → TextSelectionControls
Delegate for building the text selection handles and toolbar.
final
selectionEnabled → bool
no setter
showCursor → bool
Whether to show cursor.
final
showSelectionHandles → bool
Whether to show selection handles.
final
textCapitalization → TextCapitalization
Configures how the platform keyboard will select an uppercase or lowercase keyboard.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultContextMenuBuilder(BuildContext context, RawEditorState state) → Widget