RichTextSpanModel class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
hideToolbar()
→ void
-
隐藏工具条
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifierLazy()
→ void
-
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update({String text = "", Map<String, dynamic> wordsPinyinMap = const {}, List<List<int>> markRanges = const []})
→ void
-
更新内容
text 文本
wordsPinyinMap 拼音字标注