LinkText class

Inheritance

Constructors

LinkText({String? targetText, TextStyle? textStyle, SpecialTextGestureTapCallback? tapCallback, int? start, Map<String, dynamic>? extrasMap})

Properties

extrasMap → Map<String, dynamic>?
扩展map(用于携带自定义数据)
final
hashCode → int
The hash code for this object.
no setterinherited
isMarkPinyin ↔ bool
是否标注拼音
getter/setter pairinherited
offset → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int?
final
startFlag → String?
no setterinherited
tapCallback → SpecialTextGestureTapCallback?
final
targetText → String?
final
textStyle → TextStyle?
final
textType → SpecialTextType
no setterinherited

Methods

appendContent(String? value) → void
append text of SpecialText
inherited
finishText() → InlineSpan
finish SpecialText
override
getContent() → String
get content of SpecialText
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOffset(int offset) → void
inherited
setStartFlag(String startFlag) → void
inherited
setTextType(SpecialTextType textType) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

linkKey → const String